Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Error ¶
type Error struct {
Err error // the underlying error
// The error message of the underlying error, or an empty string if
// the underlying error is nil.
Code string
Message string
}
func (*Error) Unwrap ¶
Unwrap follows the Unwrap convention introduced in Go 1.13, See https://blog.golang.org/go1.13-errors
Click to show internal directories.
Click to hide internal directories.